import useSWR from "swr";
import { capitalizeFirstLetter } from "../../models/capitalizeFirstLetter";
import fetcher from "../../models/fetcher";
import LightList from "../LightsList/LightsList";
import { v4 as uuidv4 } from 'uuid';

interface ILandingLightsProps {
  roomsList: {name: string}[];
}

export const LandingLights = ({ roomsList }: ILandingLightsProps) => {
  const lightsComponentList = roomsList.map(room => {
    const { data: dataLights, error: errorLights } = useSWR(`${import.meta.env.VITE_API}/api/room/lights?roomName=${room.name}`, fetcher);

    if (errorLights) return <div key={uuidv4()}>failed to load information about {room.name} lights</div>
    if (!dataLights) return <div key={uuidv4()}>loading information about {room.name} lights...</div>
    const header = capitalizeFirstLetter(room.name) + ' lights'
    return <LightList header={header} lights={dataLights} roomName={room.name} key={uuidv4()} />
  })
  return (
    <>
      {lightsComponentList}
    </>
  );
}
